
function  [SP_POINTS] = MakeFeatures(img);

% MAKEFEATURES Corner Type Image Feature Point Extraction 
%
% Description
% [SP_POINTS] = MakeFeatures(img) extracts corner type image features 
%               from the image "img" using end-stopped wavelets, First
%               Derivative of Gaussian Operator and maxima searching.
% Algorithm I/O:
%   SP_POINTS: 0-1-array of image feature points/corners
%   img: Input Image
%   nsp: Number of feature points
%   M: half size of square to fit locally
%   r: size of square for changes, may be any
%   s: the minimum allowed distance between SP candidate and straight line
%   da: determines the interval, where the angle between SP candidate's edges has to be from
%   ds: maximum allowed curvature divergence for straight line candidates 
%   sps: boolean matrix as X where points are
%   t: the minimum allowed distance between two significant points
%
%   Ref: 
%   V. Monga and B. L. Evans, "Robust perceptual image hashing
%   using feature points," Proc. IEEE Conf. on Image Processing, 
%   Oct. 2004.  

% Authored 2005 by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

 prompt={'Number of Feature points:','MEAN computation size:','SIGN change size:','Distance to STRAIGHT lines:','ANGLE difference allowance:','STRAIGHTNESS allowance:','MIN distance between SPS points:'};
    def={'64','2','4','1','7','3','8'};
    title = 'Feature Point Based Hashing Parameters';
    lineNo = 1;
     answer=inputdlg(prompt,title,lineNo,def);
   
   nsp=str2num(answer{1});
   M=str2num(answer{2});
	r=str2num(answer{3});
	s=str2num(answer{4});
   da=str2num(answer{5});
   ds=str2num(answer{6});
  	t=str2num(answer{7});

 img_double = double(img);
   
 [HGF,C,HM,ANG,POS1,POS2] = findCornerStep1(img_double,1,M,1,r);
 [SP_POINTS] = findCornerStep2(img_double,1,nsp,HGF,C,HM,ANG,M,r,s,da,ds,t);
 %size(RESULT);

