
function [trans] = boxdistrans(A,B,tl,th,C1);

% BOXDISTRANS  Calculates the box distance transform
%
% Description
%   A is the reference image
%   B is the candidate images
%   tl and th are restrictions on the affine transformation
%   C1 is the distance transform of the original image
%
% Ref:
% 1.) V. Monga, D. Vats and B. L. Evans, ``Image Authentication Under Geometric 
% Attacks Via Structure Matching'', Proc. IEEE Int. Conf. on Multimedia and Expo, 
% pp. 200-203, Netherlands, 2005.
% 2.) W. J. Rucklidge, "Locating objects using the hausdorff distance," IEEE
% Int. Conf. on Computer Vision, 1995.

% Authored January 2005 by Divyanshu Vats, modified by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

B1 = affinefeatnot(B,tl);
BB = affinefeatnot(B,th);

dx = BB.x - B1.x;
dy = BB.y - B1.y;

[szxx szyy] = size(C1);
dxdy = dx.*dy;

[dd loc] = max(dxdy);
loc;
refdx = abs(dx(loc));
refdy = abs(dy(loc));

B1 = affinefeatnot1(B,tl);
BB = affinefeatnot1(B,th);

%% selecting points from B1 that
%% that are within 1 to 512

for v = 1:length(B1.x)
    
    if refdx == 0
        B2.x{v} = B1.x(v);
    else
        B2.x{v} = B1.x(v)+(0:1:refdx)*(dx(v)/refdx);
    end
    
    if refdy == 0
        B2.y{v} = B1.y(v);
    else
        B2.y{v} = B1.y(v)+(0:1:refdy)*(dy(v)/refdy);
    end
    
   % B2.x{v} = floor(B2.x{v});
   % B2.y{v} = floor(B2.y{v});    
    
    xx = find(B2.x{v}+szxx*0.4+1 < szxx);
    B2.x{v} = B2.x{v}(xx);
    
    xx = find(B2.y{v}+szyy*0.4+1 < szyy);
    
    B2.y{v} = B2.y{v}(xx);
    if (~isempty(B2.x{v}) & ~isempty(B2.y{v}))
        xx = B2.x{v}(end)*ones(1,refdx+1);
        xx(1:length(B2.x{v})) = B2.x{v};
        B2.x{v} = xx;
        clear xx;
        xx = B2.y{v}(end)*ones(1,refdy+1);
        xx(1:length(B2.y{v})) = B2.y{v};
        B2.y{v} = xx;
    end
end

ind = 1;

ff = zeros(refdx+1,refdy+1);

for j = 1:length(B2.x);
    ff = C1(round(szxx*0.4+B2.x{j}),round(szyy*0.4+B2.y{j}))+ff;
    %ff = C1(round(szxx*0.4+B2.x{j}),round(szyy*0.4+B2.y{j}));
end
al = 0.8;

ff1 = min(min(ff));

stdxa = max(std(A.x),std(A.y));
stdxb = max(std(B.x),std(B.y));
stdxx = max(stdxa,stdxb);
if isempty(ff1)
    trans = Inf;
else
    %trans = ff1/length(A.x);
    trans = ff1/(length(A.x)*stdxx);
end