

function [hashVec, out] = featurepointhash(imgin)

% FEATUREPOINTHASH Image Hashing by visually significant Feature
%                  Point Extraction 
%
%  Description
%  [hashVec] = featurepointhash(imgin) extracts
%  hash vector hashVec from input image "imgin" by using
%  end-stopped wavelets to get image feature points. Explanation of input 
%  parameters to the hash algorithm can be found in MakeFeatures. 
%  Algorithm details can be found in the reference below.
%
%  See also HASHBYSVD, WAVELETHASH
%
%   Ref: 
%   V. Monga and B. L. Evans, "Robust perceptual image hashing
%   using feature points," Proc. IEEE Conf. on Image Processing, 
%   Oct. 2004.  

% Authored 2005 by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

img = double(imgin);

[SP_POINTS] = MakeFeatures(img);

% Show feature points
out = 1- SP_POINTS;
out = im2uint8(out);

hashVec = createstruct(out);

