
function [tlbb, thbb, inc] = finalcalsize(img, i1, i2, i3, i4, t1, t2, A, B);

% FINALCALSIZE  Computes the cell size over which to optimize 
%                the affine transform parameters 
%
% Description
% The goal is to determine if the feature set B is an affine transformed version  
% of the feature set A. 
% Affine Transformation is represented by y = R*x + t
% where R = [i1 i2; i3 i4] and t = transpose([t1 t2])
%
% See also HAUSDORFF, AFFINEFEAT, AFFINEFEATNOT
%
% Ref:
% V. Monga, D. Vats and B. L. Evans, ``Image Authentication Under Geometric 
% Attacks Via Structure Matching'', Proc. IEEE Int. Conf. on Multimedia and Expo, 
% pp. 200-203, Netherlands, 2005.

% Authored 2005 by Divyanshu Vats, modified by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

i1val = i1; N1 = length(i1val);
i2val = i2; N2 = length(i2val);
i3val = i3; N3 = length(i3val);
i4val = i4; N4 = length(i4val);
t1val = t1; T1 = length(t1val);
t2val = t2; T2 = length(t2val);
n1x = 2;n2x = 2;n3x = 2;n4x = 2;t1x = 2;t2x = 2;

if N1==1
    n1x = 1;
end

if N2==1
    n2x = 1;
end

if N3==1
    n3x = 1;
end
if N4==1
    n4x = 1;
end
if T1==1
    t1x = 1;
end
if T2==1
    t2x = 1;
end

ind = [floor(N1/2)+1 floor(N2/2)+1 floor(N3/2)+1 ...
    floor(N4/2)+1 floor(T1/2)+1 floor(T2/2)+1];

ind1 = [1 ind(1)];
ind2 = [1 ind(2)];
ind3 = [1 ind(3)];
ind4 = [1 ind(4)];
ind5 = [1 ind(5)];
ind6 = [1 ind(6)];

i1val(N1+1) = i1(end);
i2val(N2+1) = i2(end);
i3val(N3+1) = i3(end);
i4val(N4+1) = i4(end);
t1val(T1+1) = t1(end);
t2val(T2+1) = t2(end);

kk = 1;
tl = cell(1,2^6);

for j1 = 1:n1x;
    for j2 = 1:n2x;
        for j3 = 1:n3x;
            for j4 = 1:n4x;
                for j5 = 1:t1x;
                    for j6 = 1:t2x;
                        tl{kk} = [i1val(ind1(j1)) i2val(ind2(j2)); ...
                                i3val(ind3(j3)) i4val(ind4(j4)); ...
                                t1val(ind5(j5)) t2val(ind6(j6))];
                        tlind{kk} = [ind1(j1) ind2(j2); ind3(j3) ind4(j4); ind5(j5) ind6(j6)];
                        th{kk} = [i1val(ind1(j1)+floor(N1/2)) i2val(ind2(j2)+floor(N2/2));...
                                i3val(ind3(j3)+floor(N3/2)) i4val(ind4(j4)+floor(N4/2));...
                                t1val(ind5(j5)+floor(T1/2)) t2val(ind6(j6)+floor(T2/2))];
                        dx{kk} = (th{kk}(1,1)-tl{kk}(1,1)) + (th{kk}(1,2)-tl{kk}(1,2)) + (th{kk}(3,1)-tl{kk}(3,1));
                        dy{kk} = (th{kk}(2,1)-tl{kk}(2,1)) + (th{kk}(2,2)-tl{kk}(2,2)) + (th{kk}(3,2)-tl{kk}(3,2));
                        kk = kk + 1;
                    end
                end
            end
        end
    end
end

C = img;
C = im2double(C);
[szx szy] = size(C);
C2 = ones(4*szx+szx,4*szy+szy);
C2(2*szx+1:2*szx+szx,2*szy+1:2*szy+szy) = C;
C1 = bwdist(~C2);
clear C2 C

for i = 1:length(th)
    boxtr(i) = boxdistrans(A,B,tl{i},th{i},C1);
end

jj = min(boxtr)*1.2;
hh = find(boxtr < jj);
%jj = min(boxtr);
jj;
boxtr;   
inc = 0;
newtl{1} = 0;
newth{1} = 0;

len1 = length(hh);

%while inc == 0
for ghg = 1:1
    for b = 1:len1
       tlk = tl{hh(b)};
       thk = th{hh(b)};
       [newtl newth inc jj1] = furthercal(tlk,thk,A,B,C1,newtl,newth,jj);
    end
    jj1;
    tl = newtl;
    th = newth;
    clear newtl newth;
    if ghg==100
        for kk = 1:length(tl)-1
            h(kk) = hausdorff(A,affinefeatnot1(B,tl{kk}));
        end
        [min11 loc1] = min(h)
        loc2 = find(h < min11*1.2);
        tls = tl(loc2);
        ths = th(loc2);    
        clear tl th
        tl = tls;
        th = ths;
        tl{end+1} = 0;
        th{end+1} = 0;
        clear ths tls
        jj = 10;
    end
    newtl{1} = 0;
    newth{1} = 0;
    len1 = length(tl)-1;
    hh = 1:len1;
end

tlbb = tl;
thbb = th;