
function [newtl, newth, inc, jj] = furthercal(tlk, thk, A, B, C1, newtl, newth, jj);

% FURTHERCAL  Recurses to eliminate incorrect transformations 
%
% Description
% Eliminates affine transformations using a process similar to binary
% search. Successive recursive calls to this function slowly reduces the 
% number of possible affine mappings. Details can be found in the reference below.
%
% Ref:
% 1.) W. J. Rucklidge, "Locating objects using the hausdorff distance", IEEE
% Int. Conf. on Computer Vision, 1995.

% Authored January 2005 by Divyanshu Vats, modified by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

i1val = tlk(1,1):1:thk(1,1);
i2val = tlk(1,2):1:thk(1,2);
i3val = tlk(2,1):1:thk(2,1);
i4val = tlk(2,2):1:thk(2,2);
t1val = tlk(3,1):thk(3,1);
t2val = tlk(3,2):thk(3,2);

N1 = length(i1val);
N2 = length(i2val);
N3 = length(i3val);
N4 = length(i4val);
T1 = length(t1val);
T2 = length(t2val);

n1x = 2; n2x = 2; n3x = 2; n4x = 2; t1x = 2; t2x = 2;

ind = [floor(N1/2)+1 floor(N2/2)+1 floor(N3/2)+1 ...
    floor(N4/2)+1 floor(T1/2)+1 floor(T2/2)+1];

if N1==1
    n1x = 1;
end

if N2==1
    n2x = 1;
end

if N3==1
    n3x = 1;
end
if N4==1
    n4x = 1;
end
if T1==1
    t1x = 1;
end
if T2==1
    t2x = 1;
end

ind1 = [1 ind(1)];
ind2 = [1 ind(2)];
ind3 = [1 ind(3)];
ind4 = [1 ind(4)];
ind5 = [1 ind(5)];
ind6 = [1 ind(6)];

i1val(N1+1) = thk(1,1);
i2val(N2+1) = thk(1,2);
i3val(N3+1) = thk(2,1);
i4val(N4+1) = thk(2,2);
t1val(T1+1) = thk(3,1);
t2val(T2+1) = thk(3,2);

kk = 1;

for j1 = 1:n1x;
    for j2 = 1:n2x;
        for j3 = 1:n3x;
            for j4 = 1:n4x;
                for j5 = 1:t1x;
                    for j6 = 1:t2x;
                        tl{kk} = [i1val(ind1(j1)) i2val(ind2(j2)); ...
                                i3val(ind3(j3)) i4val(ind4(j4)); ...
                                t1val(ind5(j5)) t2val(ind6(j6))];
                        tlind{kk} = [ind1(j1) ind2(j2); ind3(j3) ind4(j4); ind5(j5) ind6(j6)];
                        th{kk} = [i1val(ind1(j1)+floor((N1-1)/2)) i2val(ind2(j2)+floor((N2-1)/2));...
                                i3val(ind3(j3)+floor((N3-1)/2)) i4val(ind4(j4)+floor((N4-1)/2));...
                                t1val(ind5(j5)+floor((T1-1)/2)) t2val(ind6(j6)+floor((T2-1)/2))];
                        dx{kk} = (th{kk}(1,1)-tl{kk}(1,1)) + (th{kk}(1,2)-tl{kk}(1,2)) + (th{kk}(3,1)-tl{kk}(3,1));
                        dy{kk} = (th{kk}(2,1)-tl{kk}(2,1)) + (th{kk}(2,2)-tl{kk}(2,2)) + (th{kk}(3,2)-tl{kk}(3,2));
                        kk = kk + 1;
                    end
                end
            end
        end
    end
end

for i = 1:length(th)
    boxtr(i) = boxdistrans(A,B,tl{i},th{i},C1);
    if boxtr(i) < jj;
        newtl{length(newtl)} = tl{i};
        newth{length(newth)} = th{i};
        newtl{length(newtl)+1} = 0;
        newth{length(newth)+1} = 0;
    end
end

inc = 0;
jj = min(boxtr)*1.2;
if max([N1,N2,N3,N4,T1,T2]) <= 2
    inc = 1;
end