
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.
%
% The hashingdemo performs an automated test for a
% perceptual match of two images. This is done by
% computing hashes from the two images and comparing
% the hash vectors for a meaningful notion of distance.
%
% To start the demo type hashingdemo from the command prompt.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%  
% The GNU Public License is available in the file LICENSE, or you
% can write to the Free Software Foundation, Inc., 59 Temple Place -
% Suite 330, Boston, MA 02111-1307, USA, or you can find it on the
% World Wide Web at http://www.fsf.org.
%  
% Programmers:	Vishal Monga and Divyanshu Vats
% Version:      @(#)imagauth.m 0.1 beta 01/18/05
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

function hashingdemo(action)

if nargin < 1,
   action='init';
end;

if strcmp(action,'init'),
h0 = figure('Position',[232 50 575 600], ...
   'ToolBar','none',...
   'name','Image Hashing Toolbox',...
   'NumberTitle','off',...
   'Menubar','figure');

figureColor = get(h0, 'Color');    

%Welcome textbox
h1 = uicontrol('Units','normalized', ...
   'Style', 'text', ...
   'HorizontalAlignment','center', ...
   'Units','normalized', ...
   'BackgroundColor', [1 1 1], ...
   'Min', 0, ...
   'Max', 3, ...
   'Value', [], ...
   'Enable', 'inactive', ...
   'Position',[0.05 0.76 0.36 0.17], ...
   'Callback', '', ...
   'String', {'Thank you for using', 'the Image Hashing Toolbox',...
        'please choose from one of the', 'hashing methods listed below'});

% DWT hash
DWTHdl = uicontrol( ...
    'Units','normalized',...
   'Style', 'pushbutton', ...
   'Units','normalized',...
   'Position', [0.05 0.57 0.36 0.10], ...
   'Callback', 'runWaveletHash', ...
   'String', 'DWT Based Image Hashing'); 

% Hashing by SVD
SVDHdl = uicontrol( ...
    'Units','normalized',...
   'Style', 'pushbutton', ...
   'Position', [0.05 0.46 0.36 0.10], ...
   'String', 'SVD Based Image Hash', ...
   'Callback', 'runSVDHash'); 

% Hashing by Feature Points
FPHdl = uicontrol( ...
    'Units','normalized',...
   'Style', 'pushbutton', ...
   'Position', [0.05 0.35 0.36 0.10], ...
   'String', 'Hashing Via Feature Points', ...
   'Callback', 'runFPHash'); 


% create a listbox for displaying the 'about' information
aboutListPos=[0.45,0.25,0.5,0.69];

aboutinfo = {...
'The hashingdemo performs an automated test for a' 
'perceptual match of two images. This is done by' 
'computing hashes from the two images and comparing'
'the hash vectors for a meaningful notion of distance.'
'Image hashing methods included in this demo are:'
'                                                 '
' 1. Discrete Wavelet Transform (DWT) Based Image Hash [Venkatesan et al., 2000]'
' 2. Hashing Via Singular Value Decomposition (SVD) [Kozat et al. 2004]'            
' 3. Feature Point Based Image Hashing [Monga & Evans, 2004-06]' 
'                                                     '
'As you click on any method, you are prompted to enter appropriate'
'parameters corresponding to the selected hashing method.'
'A set of good (average case) parameters appears by default.'
'For more details on algorithms and parameters, please see the readme file.'
'                                                     '
'Image Hashing research by the research group of Prof.'
'Brian L. Evans at UT Austin is described on the Web at'
'                                                      '
'http://www.ece.utexas.edu/~bevans/projects/hashing/'
' '
'This image hashing toolbox is copyright (c) 1999-2005 by'
'The University of Texas.  All Rights Reserved.'
' '
'This program is free software; you can redistribute it'
'and/or modify it under the terms of the GNU General '
'Public License as published by the Free Software '
'Foundation; either version 2 of the License, or '
'(at your option) any later version.'
' '
'This program is distributed in the hope that it will be'
'useful, but WITHOUT ANY WARRANTY; without even the implied'
'warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR'
'PURPOSE.  See the GNU General Public License for more '
'details.'
' '
'The GNU Public License is available in the file LICENSE,'
'or you can write to the Free Software Foundation, Inc.,'
'59 Temple Place - Suite 330, Boston, MA 02111-1307, USA,'
'or you can find it on the Web at http://www.fsf.org.'};


aboutListH = uicontrol( ...
   'Style', 'list', ...
   'HorizontalAlignment','left', ...
   'Units','normalized', ...
   'BackgroundColor', figureColor, ...
   'Min', 0, ...
   'Max', 3, ...
   'Value', [], ...
   'Enable', 'inactive', ...
   'Position', aboutListPos, ...
   'Callback', '', ...
   'String', aboutinfo, ...
   'Tag', 'AboutListbox');

   % help button
   labelStr='Info';
   callbackStr='helpwin hashingdemo';
   helpHndl=uicontrol( ...
      'Style','pushbutton', ...
      'Units','normalized', ...
      'Position',[0.45 0.13 0.22 0.07], ...
      'String',labelStr, ...
      'Callback',callbackStr);
  
  %close button
  backH = uicontrol( ...
   'Style', 'pushbutton', ...
   'Units', 'normalized', ...
   'Position', [0.73 0.13 0.22 0.07], ...
   'String', 'Close', ...
   'Tag', 'return', ...
   'Callback', 'close(gcbf)'); 

elseif strcmp(action,'info'),
   ttlStr = get(gcf,'name');
   myFig = gcf;
   
   topic1 =  ['IMAGE HASHING DEMO'];
   helptop1 = [...
           
       ' Image hashing methods included in this demo are:'
       '                                                 '
       ' 1. Wavelet Based Image Hash [Venkatesan et al., 2000]'
       ' 2. Hashing Via Singular Value Decomposition [Kozat. el al. 2004]'            
       ' 3. Feature Point Based Image Hashing [Monga, Evans, 2004-06]' 
       ' To start the demo type "hashingdemo" '
            
   ];
   
   
   str =  { topic1 helptop1};
   
   helpwin(str,'Topic 1','IMAGE HASHING TOOLBOX');                   
   return  

end;
