
function [out, R, t] = imagauth(img1, img2);

% IMAGAUTH  Compares hashes from two images 
%           under hausdorff distance 
%
% Description
% [out, R, t] = imagauth(img1, img2)
%   Computes hashes from input images img1 and img2 
%   Evaluates hashes for closeness in Hausdorff distance
%   Checks if img2 is a geometrically transformed version of img1
%   and computes affine transformation parameters R and t
%
% Ref:
% V. Monga, D. Vats and B. L. Evans, ``Image Authentication Under Geometric 
% Attacks Via Structure Matching'', Proc. IEEE Int. Conf. on Multimedia and Expo, 
% pp. 200-203, Netherlands, 2005.

% Authored 2005 by Divyanshu Vats, modified by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.

% Please change values of i1,i2,i3,i4,t1,t2 for suitable results
% some tweaking might need to be done in finalcalsize(...) for good results
% generating feature points
[A f_img1] = featurepointhash(img1);
[B f_img2] = featurepointhash(img2);

close all;

[A.szx A.szy] = size(img1);
[B.szx B.szy] = size(img2);
%
% Calculating initial distance between points
h = hausdorff(A,B);
%

% Variables for controlling the affine transformation
i1 = 210:240;
i2 = 80:120;
i3 = -120:-80;
i4 = 210:240;
t1 = 0;
t2 = 0;
%%%
if h > 0.15    
    [tlbb, thbb, inc] = finalcalsize(f_img2,i1,i2,i3,i4,t1,t2,A,B);
    if tlbb{1} == 0
        disp('Try to run the program again with different parameters');
        out = Inf;
    else
        for i = 1:length(tlbb)-1
            h(i) = hausdorff(B,affinefeatnot1(A,tlbb{i}));
        end
        [out loc] = min(h);
        tlk = tlbb{loc};
        thk = thbb{loc};        
    end
    if out < 0.15
    disp('T*(x) = R*x + t*');
    R = tlk(1:2,1:2)/256
    t = tlk(3,1:2)'
    else 
    disp('T*(x) = R*x + t*');
    R = tlk(1:2,1:2)/256
    t = tlk(3,1:2)'
    end
else
    disp('T*(x) = R*x + t');
    R = [1 0; 0 1]
    t = [0 0]'
    out = h;
end

ff1 = overlay(img1,f_img1);
ff2 = overlay(img2,f_img2);
imwrite(ff1,'img_feat_cand.tif');
imwrite(ff2,'img_feat_orig.tif');
disp('Images with feature points are saved as img_feat_cand.tif and img_feat_orig.tif');

