
function [hashVec] = wavelethash(imgin, wavelet, delta, key, level, numrects)

% WAVELETHASH Image Hashing by quantization of pseudo-random
%           statistics of wavelet coefficients
%  Description
%  [hashVec] = wavelethash(imgin, wavelet, delta, key, level, numrects) extracts
%  hash vector hashVec from input image "imgin". The image is divided into
%  random rectangles using the secret key "key". A wavelet decomposition to
%  level "level" is obatined, "wavelet" specifies which wavelet basis to
%  use. numrects in the number of random rectangles used. Inner product of
%  pseudo-random weights generated using the secret key with the DC sub-band 
%  of the wavelet decomposition of each random rectangle generates the components  
%  of the hash. Details can be found in the reference below.
%
%	See also HASHBYSVD, FEATUREPOINTHASH
%
%	Ref: 
%   R. Venkatesan, S. M. Koon, M. H. Jakubowski, and
%   P. Moulin, "Robust image hashing", Proc. IEEE Conf.
%   on Image Processing, pp. 664-666, Sept. 2000.

% Authored 2005 by Vishal Monga
% Copyright (c) 1999-2005 The University of Texas
% All Rights Reserved.


%% Initialization of default parameters
ratio1 = 1/4; ratio2 = 1/8;

image = double(imgin);

xszbig = size(image,2);
yszbig = size(image,1);
xsz = xszbig/(2^level);
ysz = yszbig/(2^level);

totallength = xsz*ysz;
meanlength = round(ratio1*ysz);
varlength = round(ratio2*ysz);

dwtmode('per','notext');

indata = image;

for i=1:1:level,
	 dwtmode('per','notext');
    [ca,ch,cv,cd] = dwt2(indata,wavelet);
    indata = ca;
end;

hostmat = indata;
hostvec = indata(:);

rand('state',key);
rectlengths = ceil(rand(numrects,1)*(2*varlength+1))  + meanlength - varlength - 1;
rectcoors = ceil(rand(numrects,2).*[ysz-rectlengths+1 xsz-rectlengths+1]);

%preparing the random linear transformation matrix
T = zeros(numrects,totallength);

%uniform weights in the formation of the transform matrix at this point
for i=1:1:numrects,   
   dummat = zeros(ysz,xsz);
   dummat(rectcoors(i,1):(rectcoors(i,1)+rectlengths(i)-1),rectcoors(i,2):(rectcoors(i,2)+rectlengths(i)-1)) = 1;
   dummat = dummat / sum(sum(dummat));
   T(i,:) = (dummat(:))';
end;

hostaves = T*hostvec;
hashVec = round(hostaves/delta)*delta;

return;

